==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Information/InfoAngle/ts/InfoAngle_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>InfoAngle</name>
    <message>
        <location filename="../InfoAngle.js" line="+67"/>
        <source>Specify first line</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż pierwszą linie</translatorcomment>
        <translation type="unfinished">Wskaż pierwszą linie</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Specify second line</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż drugą linie</translatorcomment>
        <translation type="unfinished">Wskaż drugą linie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="unfinished">Zrobione</translation>
    </message>
    <message>
        <location line="+88"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation type="unfinished">Kąt:</translation>
    </message>
    <message>
        <location filename="../InfoAngleInit.js" line="+2"/>
        <source>&amp;Angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Kąt
&amp;Kąt pomiędzy dwoma liniami</translatorcomment>
        <translation type="unfinished">&amp;Kąt</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Information/InfoAngle/ts/InfoAngle_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InfoAngle</name>
    <message>
        <location filename="../InfoAngle.js" line="+67"/>
        <source>Specify first line</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż pierwszą linie</translatorcomment>
        <translation>Proszę wskazać pierwszą linię</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Specify second line</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż drugą linie</translatorcomment>
        <translation>Proszę wskazać drugą linię</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location line="+88"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location filename="../InfoAngleInit.js" line="+2"/>
        <source>&amp;Angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Kąt
&amp;Kąt pomiędzy dwoma liniami</translatorcomment>
        <translation>&amp;Kąt</translation>
    </message>
</context>
</TS>
